@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, 
+ * Boston, MA 02110-1301, USA.
  */
 
 /*
@@ -29,6 +29,7 @@
  * The orginal comments are left intact above
  */
 
+#include <config.h>
 #include "gnome-cmd-includes.h"
 #include "gnome-cmd-combo.h"
 #include "gnome-cmd-style.h"
