@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -29,6 +29,7 @@
 #include "gnome-cmd-file-props-dialog.h"
 #include "gnome-cmd-main-win.h"
 #include "gnome-cmd-xfer.h"
+#include "gnome-cmd-tags-libs.h"
 #include "libgviewer/libgviewer.h"
 
 #define MAX_TYPE_LENGTH 2
@@ -78,13 +79,26 @@ destroy (GtkObject *object)
 {
     GnomeCmdFile *file = GNOME_CMD_FILE (object);
 
+#ifdef HAVE_EXIF
+    gcmd_tags_libexif_free_metadata(file);
+#endif
+
+#ifdef HAVE_IPTC
+    gcmd_tags_libiptcdata_free_metadata(file);
+#endif
+
+#ifdef HAVE_ICC
+    gcmd_tags_icclib_free_metadata(file);
+#endif
+
     if (file->info->name[0] != '.')
         DEBUG ('f', "file destroying 0x%x %s\n", (guint)file, file->info->name);
     gnome_vfs_file_info_unref (file->info);
     if (file->priv->dir_handle)
         handle_unref (file->priv->dir_handle);
 
-    if (DEBUG_ENABLED ('c')) {
+    if (DEBUG_ENABLED ('c'))
+    {
         all_files = g_list_remove (all_files, file);
         deleted_files_cnt++;
     }
@@ -97,15 +111,16 @@ destroy (GtkObject *object)
 
 
 static void
-class_init (GnomeCmdFileClass *class)
+class_init (GnomeCmdFileClass *klass)
 {
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
+    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
 
     parent_class = gtk_type_class (gnome_cmd_file_info_get_type ());
 
     object_class->destroy = destroy;
 }
 
+
 static void
 init (GnomeCmdFile *file)
 {
@@ -114,13 +129,29 @@ init (GnomeCmdFile *file)
     file->priv = g_new0 (GnomeCmdFilePrivate, 1);
     file->priv->dir_handle = NULL;
 
-    if (DEBUG_ENABLED ('c')) {
+    if (DEBUG_ENABLED ('c'))
+    {
         all_files = g_list_append (all_files, file);
         created_files_cnt++;
     }
 
     file->priv->last_update.tv_sec = 0;
     file->priv->last_update.tv_usec = 0;
+
+#ifdef HAVE_EXIF
+    file->exif.metadata = NULL;
+    file->exif.accessed = FALSE;
+#endif
+
+#ifdef HAVE_IPTC
+    file->iptc.metadata = NULL;
+    file->iptc.accessed = FALSE;
+#endif
+
+#ifdef HAVE_ICC
+    file->icc.metadata = NULL;
+    file->icc.accessed = FALSE;
+#endif
 }
 
 
@@ -333,8 +364,8 @@ gnome_cmd_file_get_path (GnomeCmdFile *finfo)
     g_return_val_if_fail (finfo != NULL, NULL);
     g_return_val_if_fail (finfo->info != NULL, NULL);
 
-    if (strcmp (finfo->info->name, "/") == 0)
-        return g_strdup ("/");
+    if (strcmp (finfo->info->name, G_DIR_SEPARATOR_S) == 0)
+        return g_strdup (G_DIR_SEPARATOR_S);
 
     if (!has_parent_dir (finfo)) {
         if (GNOME_CMD_IS_DIR (finfo)) {
@@ -706,8 +737,8 @@ do_view_file (const gchar *path, gint internal_viewer)
                         viewer = gviewer_window_file_view(arg, NULL);
                         gtk_widget_show(GTK_WIDGET(viewer));
                         gdk_window_set_icon (GTK_WIDGET(viewer)->window, NULL,
-                                             IMAGE_get_pixmap (PIXMAP_LOGO),
-                                             IMAGE_get_mask (PIXMAP_LOGO));
+                                             IMAGE_get_pixmap (PIXMAP_INTERNAL_VIEWER),
+                                             IMAGE_get_mask (PIXMAP_INTERNAL_VIEWER));
                         g_free(arg);
                     }
                     break;
@@ -878,7 +909,7 @@ void
 gnome_cmd_file_execute (GnomeCmdFile *finfo)
 {
     gchar *fpath = gnome_cmd_file_get_real_path (finfo),
-          *dpath = g_dirname (fpath),
+          *dpath = g_path_get_dirname (fpath),
           *cmd = g_strdup_printf ("./%s", finfo->info->name);
 
     run_command_indir (cmd, dpath, app_needs_terminal (finfo));
