@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -31,16 +31,16 @@
 #include "useractions.h"
 
 #include "../pixmaps/exec_wheel.xpm"
-#include "../pixmaps/menu_ftp_connect.xpm"
 
 
-/* Theese following types are slightly changed from the originals in the GnomeUI library
+/* These following types are slightly changed from the originals in the GnomeUI library
    We need special types because we neeed to place non-changeable shortcuts in the
-   menus. Another differance is that we want only mouse-clicks in the menu to generate an
+   menus. Another difference is that we want only mouse-clicks in the menu to generate an
    action, keyboard shortcuts are caught by the different components by them self */
+
 typedef enum {
     MENU_TYPE_END,        /* No more items, use it at the end of an array */
-    MENU_TYPE_ITEM,          /* Normal item, or radio item if it is inside a radioitems group */
+    MENU_TYPE_ITEM,       /* Normal item, or radio item if it is inside a radioitems group */
     MENU_TYPE_BASIC,
     MENU_TYPE_TOGGLEITEM, /* Toggle (check box) item */
     MENU_TYPE_RADIOITEMS, /* Radio item group */
@@ -430,10 +430,10 @@ map (GtkWidget *widget)
 
 
 static void
-class_init (GnomeCmdMainMenuClass *class)
+class_init (GnomeCmdMainMenuClass *klass)
 {
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
+    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
+    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
     parent_class = gtk_type_class (gtk_menu_bar_get_type ());
     object_class->destroy = destroy;
@@ -473,7 +473,7 @@ init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_Properties..."), "Alt+ENTER", NULL,
             file_properties, NULL,
-            GNOME_APP_PIXMAP_NONE, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PROPERTIES,
             NULL
         },
         MENUTYPE_SEPARATOR,
@@ -663,7 +663,7 @@ init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_Bookmark this Directory..."), "", NULL,
             bookmarks_add_current, NULL,
-            GNOME_APP_PIXMAP_NONE, NULL,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_ADD,
             NULL
         },
         {
@@ -693,7 +693,7 @@ init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("_Options..."), "Ctrl+O", NULL,
             options_edit, NULL,
-            GNOME_APP_PIXMAP_STOCK, GNOME_STOCK_MENU_PROP,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PREFERENCES,
             NULL
         },
         {
@@ -710,13 +710,13 @@ init (GnomeCmdMainMenu *main_menu)
         {
             MENU_TYPE_ITEM, _("FTP _Connect..."), "Ctrl+F", NULL,
             connections_ftp_connect, NULL,
-            GNOME_APP_PIXMAP_DATA, menu_ftp_connect_xpm,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CONNECT,
             NULL
         },
         {
             MENU_TYPE_ITEM, _("FTP _Quick Connect..."), "Ctrl+G", NULL,
             connections_ftp_quick_connect, NULL,
-            GNOME_APP_PIXMAP_DATA, menu_ftp_connect_xpm,
+            GNOME_APP_PIXMAP_STOCK, GTK_STOCK_CONNECT,
             NULL
         },
         MENUTYPE_END
@@ -730,6 +730,24 @@ init (GnomeCmdMainMenu *main_menu)
             GNOME_APP_PIXMAP_STOCK, GTK_STOCK_HELP,
             NULL
         },
+        {
+            MENU_TYPE_ITEM, _("_Keyboard Shortcuts"), "", NULL,
+            help_keyboard, NULL,
+            GNOME_APP_PIXMAP_NONE, 0,
+            NULL
+        },
+        {
+            MENU_TYPE_ITEM, _("GNOME Commander on the _Web"), "", NULL,
+            help_web, NULL,
+            GNOME_APP_PIXMAP_NONE, 0,
+            NULL
+        },
+        {
+            MENU_TYPE_ITEM, _("Report a _Problem"), "", NULL,
+            help_problem, NULL,
+            GNOME_APP_PIXMAP_NONE, 0,
+            NULL
+        },
         MENUTYPE_SEPARATOR,
         {
             MENU_TYPE_ITEM, _("_About"), "", NULL,
