@@ -14,13 +14,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef __GNOME_CMD_PATTERNSEL_DIALOG_H__
 #define __GNOME_CMD_PATTERNSEL_DIALOG_H__
 
 #include "gnome-cmd-file-list.h"
 
+G_BEGIN_DECLS
 
 #define GNOME_CMD_PATTERNSEL_DIALOG(obj) \
     GTK_CHECK_CAST (obj, gnome_cmd_patternsel_dialog_get_type (), GnomeCmdPatternselDialog)
@@ -55,9 +56,6 @@ gnome_cmd_patternsel_dialog_new (GnomeCmdFileList *fl, gboolean mode);
 GtkType
 gnome_cmd_patternsel_dialog_get_type (void);
 
+G_END_DECLS
 
-
-
-#endif //__GNOME_CMD_PATTERNSEL_DIALOG_H__
-
-
+#endif // __GNOME_CMD_PATTERNSEL_DIALOG_H__
