@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -617,7 +617,7 @@ on_goto (GtkButton *button, GnomeCmdSearchDialog *dialog)
         return;
 
     fpath = gnome_cmd_file_get_path (finfo);
-    dpath = g_dirname (fpath);
+    dpath = g_path_get_dirname (fpath);
 
     fs = gnome_cmd_main_win_get_active_fs (main_win);
     gnome_cmd_file_selector_goto_directory (fs, dpath);
@@ -699,10 +699,10 @@ map (GtkWidget *widget)
 
 
 static void
-class_init (GnomeCmdSearchDialogClass *class)
+class_init (GnomeCmdSearchDialogClass *klass)
 {
-    GtkObjectClass *object_class = GTK_OBJECT_CLASS (class);
-    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (class);
+    GtkObjectClass *object_class = GTK_OBJECT_CLASS (klass);
+    GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
     parent_class = gtk_type_class (gnome_cmd_dialog_get_type ());
 
