@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 #ifndef __GNOME_CMD_TYPES_H__
 #define __GNOME_CMD_TYPES_H__
@@ -24,6 +24,7 @@ typedef gchar* GnomeCmdDateFormat;
 
 #include "gnome-cmd-con.h"
 
+G_BEGIN_DECLS
 
 typedef enum
 {
@@ -98,5 +99,6 @@ typedef struct {
     GnomeCmdBookmarkGroup *group;
 } GnomeCmdBookmark;
 
+G_END_DECLS
 
-#endif //__GNOME_CMD_TYPES_H__
+#endif // __GNOME_CMD_TYPES_H__
