@@ -14,12 +14,14 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __HANDLE_H__
 #define __HANDLE_H__
 
+G_BEGIN_DECLS
+
 typedef struct
 {
     gint ref_count;
@@ -33,5 +35,6 @@ void     handle_ref (Handle *h);
 void     handle_unref (Handle *h);
 gpointer handle_get_ref (Handle *h);
 
+G_END_DECLS
 
-#endif //__HANDLE_H__
+#endif // __HANDLE_H__
