@@ -18,8 +18,9 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
+
 #ifndef __LIB_GVIEWER_H__
 #define __LIB_GVIEWER_H__
 
@@ -28,6 +29,7 @@
 #include <gtk/gtktable.h>
 
 #include "gvtypes.h"
+#include "viewer-utils.h"
 #include "fileops.h"
 #include "inputmodes.h"
 #include "datapresentation.h"
@@ -36,5 +38,8 @@
 #include "text-render.h"
 #include "viewer-widget.h"
 #include "viewer-window.h"
+#include "search-dlg.h"
+#include "searcher.h"
+#include "search-progress-dlg.h"
 
 #endif
