@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -69,7 +69,7 @@ get_selected_file ()
     GnomeCmdFile *finfo = gnome_cmd_file_list_get_selected_file (get_active_fl ());
 
     if (!finfo)
-        create_error_dialog ("No file selected");
+        create_error_dialog (_("No file selected"));
     return finfo;
 }
 
@@ -292,8 +292,16 @@ file_exit                           (GtkMenuItem     *menuitem,
 {
     gint x, y;
 
-    gdk_window_get_root_origin (GTK_WIDGET (main_win)->window, &x, &y);
-    gnome_cmd_data_set_main_win_pos (x, y);
+    switch (gnome_cmd_data_get_main_win_state())
+    {
+        case GDK_WINDOW_STATE_MAXIMIZED:
+        case GDK_WINDOW_STATE_FULLSCREEN:
+        case GDK_WINDOW_STATE_ICONIFIED:
+                break;
+        default:
+                gdk_window_get_root_origin (GTK_WIDGET (main_win)->window, &x, &y);
+                gnome_cmd_data_set_main_win_pos (x, y);
+    }
 
     gtk_widget_destroy (GTK_WIDGET (main_win));
 }
@@ -349,7 +357,7 @@ edit_copy_fnames                    (GtkMenuItem     *menuitem,
     sfl = gnome_cmd_file_list_sort_selection (sfl, fl);
 
     for (i = sfl; i; i = i->next) 
-	{
+    {
         GnomeCmdFile *finfo = GNOME_CMD_FILE (i->data);
 
         if (finfo)
@@ -689,31 +697,37 @@ void
 help_help                           (GtkMenuItem     *menuitem,
                                      gpointer        not_used)
 {
-    gchar *link_id = NULL;
+    gnome_cmd_help_display("gnome-commander.xml",NULL);
+}
+
+
+void
+help_keyboard                       (GtkMenuItem     *menuitem,
+                                     gpointer        not_used)
+{
+    gnome_cmd_help_display("gnome-commander.xml","gnome-commander-keyboard");
+}
+
+
+void
+help_web                            (GtkMenuItem     *menuitem,
+                                     gpointer        not_used)
+{
     GError *error = NULL;
 
-    gnome_help_display ("gnome-commander.xml", link_id, &error);
+    if (!gnome_url_show("http://www.nongnu.org/gcmd/", &error))
+        gnome_cmd_error_message(_("There was an error opening home page."), error);
+}
 
-    if (error != NULL)
-    {
-        GtkWidget *dialog;
 
-        dialog = gtk_message_dialog_new (NULL,
-                         GTK_DIALOG_DESTROY_WITH_PARENT,
-                         GTK_MESSAGE_ERROR,
-                         GTK_BUTTONS_CLOSE, 
-                         _("There was an error displaying help."));
-
-        gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), error->message);
-                              
-        g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (gtk_widget_destroy), NULL);
-
-        gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
-        gtk_widget_show (dialog);
-
-        g_error_free (error);
-    }
+void
+help_problem                        (GtkMenuItem     *menuitem,
+                                     gpointer        not_used)
+{
+    GError *error = NULL;
 
+    if (!gnome_url_show("http://bugzilla.gnome.org/browse.cgi?product=gnome-commander", &error))
+        gnome_cmd_error_message(_("There was an error reporting problem."), error);
 }
 
 
