@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #include <config.h>
@@ -333,7 +333,7 @@ type2string (GnomeVFSFileType type, gchar *buf, guint max)
 {
     char *s;
 
-    switch (type) 
+    switch (type)
     {
         case GNOME_VFS_FILE_TYPE_UNKNOWN:
             s = "?";
@@ -342,7 +342,7 @@ type2string (GnomeVFSFileType type, gchar *buf, guint max)
             s = " ";
             break;
         case GNOME_VFS_FILE_TYPE_DIRECTORY:
-            s = "/";
+            s = G_DIR_SEPARATOR_S;
             break;
         case GNOME_VFS_FILE_TYPE_SYMBOLIC_LINK:
             s = "@";
@@ -376,7 +376,7 @@ void name2string (gchar *filename, gchar *buf, guint max)
 
 void perm2string (GnomeVFSFilePermissions p, gchar *buf, guint max)
 {
-    switch (gnome_cmd_data_get_perm_disp_mode ()) 
+    switch (gnome_cmd_data_get_perm_disp_mode ())
     {
         case GNOME_CMD_PERM_DISP_MODE_TEXT:
             perm2textstring (p, buf, max);
@@ -719,8 +719,8 @@ void mime_exec_multiple (GList *files, GnomeCmdApp *app)
 
     g_return_if_fail (files != NULL);
     g_return_if_fail (app != NULL);
-	
-    for ( ; files; files = files->next ) 
+
+    for ( ; files; files = files->next )
     {
         GnomeCmdFile *finfo = (GnomeCmdFile*)files->data;
 
@@ -899,7 +899,7 @@ GnomeVFSFileSize calc_tree_size (const GnomeVFSURI *dir_uri)
     if (!list)
         return 0;
 
-    for ( tmp = list; tmp; tmp = tmp->next ) 
+    for ( tmp = list; tmp; tmp = tmp->next )
     {
         GnomeVFSFileInfo *info = (GnomeVFSFileInfo*)tmp->data;
         if (strcmp (info->name, ".") != 0 && strcmp (info->name, "..") != 0) {
@@ -1082,16 +1082,19 @@ void set_cursor_busy_for_widget (GtkWidget *widget)
         gtk_main_iteration();
 }
 
+
 void set_cursor_default_for_widget (GtkWidget *widget)
 {
     gdk_window_set_cursor (widget->window, NULL);
 }
 
+
 void set_cursor_busy (void)
 {
     set_cursor_busy_for_widget (GTK_WIDGET (main_win));
 }
 
+
 void set_cursor_default (void)
 {
     set_cursor_default_for_widget (GTK_WIDGET (main_win));
@@ -1116,7 +1119,7 @@ GList *app_get_linked_libs (GnomeCmdFile *finfo)
 
     if (!fd) return NULL;
 
-    while ((s = fgets (tmp, 256, fd)))
+    while ((s = fgets (tmp, sizeof(tmp), fd)))
     {
         char **v = g_strsplit (s, " ", 1);
         if (v) {
@@ -1175,7 +1178,7 @@ gchar *get_temp_download_filepath (const gchar *fname)
         }
     }
 
-    return g_build_path ("/", tmp_dir, tmp_file_dir, fname, NULL);
+    return g_build_path (G_DIR_SEPARATOR_S, tmp_dir, tmp_file_dir, fname, NULL);
 }
 
 
@@ -1184,7 +1187,7 @@ void remove_temp_download_dir (void)
     const gchar *tmp_dir = g_get_tmp_dir ();
 
     if (tmp_file_dir) {
-        gchar *path = g_build_path ("/", tmp_dir, tmp_file_dir, NULL);
+        gchar *path = g_build_path (G_DIR_SEPARATOR_S, tmp_dir, tmp_file_dir, NULL);
         gchar *command = g_strdup_printf ("rm -rf %s", path);
         g_free (path);
         system (command);
@@ -1266,6 +1269,7 @@ gchar *unix_to_unc (const gchar *path)
     return out;
 }
 
+
 gchar *unc_to_unix (const gchar *path)
 {
     gchar *out;
@@ -1445,14 +1449,41 @@ void patlist_free (GList *pattern_list)
 
 gboolean patlist_matches (GList *pattern_list, const gchar *s)
 {
-    GList *tmp = pattern_list;
-    gint fn_flags = FNM_NOESCAPE|FNM_CASEFOLD;
+    GList *tmp;
 
-    while (tmp) {
-        if (fnmatch ((gchar*)tmp->data, s, fn_flags) == 0)
+    for (tmp = pattern_list; tmp; tmp = tmp->next)
+        if (fnmatch ((gchar*)tmp->data, s, FNM_NOESCAPE|FNM_CASEFOLD) == 0)
             return TRUE;
-        tmp = tmp->next;
-    }
 
     return FALSE;
 }
+
+
+void gnome_cmd_error_message(const gchar *title, GError *error)
+{
+    GtkWidget *dialog = gtk_message_dialog_new (NULL,
+                                                GTK_DIALOG_DESTROY_WITH_PARENT,
+                                                GTK_MESSAGE_ERROR,
+                                                GTK_BUTTONS_CLOSE,
+                                                title);
+
+    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog), error->message);
+
+    g_signal_connect (G_OBJECT (dialog), "response", G_CALLBACK (gtk_widget_destroy), NULL);
+
+    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
+    gtk_widget_show (dialog);
+
+    g_error_free (error);
+}
+
+
+void gnome_cmd_help_display(const gchar *file_name, const gchar *link_id)
+{
+    GError *error = NULL;
+
+    gnome_help_display (file_name, link_id, &error);
+
+    if (error != NULL)
+        gnome_cmd_error_message(_("There was an error displaying help."), error);
+}
