@@ -14,7 +14,7 @@
 
   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
-  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
 #ifndef __UTILS_H__
@@ -25,6 +25,8 @@
 #include "gnome-cmd-pixmap.h"
 #include "gnome-cmd-app.h"
 
+G_BEGIN_DECLS
+
 gboolean DEBUG_ENABLED (gchar flag);
 void DEBUG (gchar flag, const gchar *fmt, ...);
 void warn_print (const gchar *fmt, ...);
@@ -115,4 +117,9 @@ GList *patlist_new (const gchar *pattern_string);
 void patlist_free (GList *pattern_list);
 gboolean patlist_matches (GList *pattern_list, const gchar *s);
 
-#endif //__UTILS_H__
+void gnome_cmd_error_message(const gchar *title, GError *error);
+void gnome_cmd_help_display(const gchar *file_name, const gchar *link_id);
+
+G_END_DECLS
+
+#endif // __UTILS_H__
